You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@servicemix.apache.org by jb...@apache.org on 2011/02/04 10:05:55 UTC

svn commit: r1067118 [6/7] - in /servicemix/components/trunk: ./ bindings/servicemix-cxf-bc/ bindings/servicemix-file/ bindings/servicemix-file/src/main/java/org/apache/servicemix/file/ bindings/servicemix-file/src/test/java/org/apache/servicemix/file/...

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/osgi/EndpointTracker.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/osgi/EndpointTracker.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/osgi/EndpointTracker.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/osgi/EndpointTracker.java Fri Feb  4 09:05:47 2011
@@ -17,24 +17,25 @@
 package org.apache.servicemix.common.osgi;
 
 import java.util.Map;
-import java.util.concurrent.ConcurrentHashMap;
 
 import javax.jbi.management.DeploymentException;
 
 import org.apache.servicemix.common.Endpoint;
 import org.apache.servicemix.common.DefaultComponent;
 import org.apache.servicemix.common.DefaultServiceUnit;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
+ * <p>
  * This class is used by components bundles to track endpoints that they know about.
  * Endpoints are wrapped into {@link EndpointWrapper} interfaces to be able to access
  * the underlying object easily and bypass spring-DM proxies.
+ * </p>
  */
 public class EndpointTracker {
 
-    private static final Log LOGGER = LogFactory.getLog(EndpointTracker.class);
+    private final Logger logger = LoggerFactory.getLogger(EndpointTracker.class);
 
     protected DefaultComponent component;
 
@@ -47,14 +48,10 @@ public class EndpointTracker {
     }
 
     public void register(EndpointWrapper wrapper, Map properties) throws Exception {
-        if (LOGGER.isDebugEnabled()) {
-            LOGGER.debug("[" + component.getComponentName() + "] Endpoint registered with properties: " + properties);
-        }
+        logger.debug("[" + component.getComponentName() + "] Endpoint registered with properties: " + properties);
         Endpoint endpoint = wrapper.getEndpoint();
         if (component.isKnownEndpoint(endpoint)) {
-            if (LOGGER.isDebugEnabled()) {
-    	        LOGGER.debug("[" + component.getComponentName() + "] Endpoint recognized");
-            }
+            logger.debug("[" + component.getComponentName() + "] Endpoint recognized");
             try {
                 OsgiServiceUnit su = new OsgiServiceUnit(component, endpoint, wrapper.getClassLoader());
                 component.getRegistry().registerServiceUnit(su);

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/osgi/EndpointWrapper.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/osgi/EndpointWrapper.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/osgi/EndpointWrapper.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/osgi/EndpointWrapper.java Fri Feb  4 09:05:47 2011
@@ -19,11 +19,13 @@ package org.apache.servicemix.common.osg
 import org.apache.servicemix.common.Endpoint;
 
 /**
+ * <p>
  * The EndpointWrapper is a very simple interface that wraps an Endpoint.
  * The main purpose of this wrapper is that Spring-DM creates proxy when using
  * collections, so that we don't have access to the real class anymore and can not
  * do anything based on the class itself.  Going through a wrapper works around
  * this problem.
+ * </p>
  */
 public interface EndpointWrapper {
 

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/Consumes.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/Consumes.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/Consumes.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/Consumes.java Fri Feb  4 09:05:47 2011
@@ -19,8 +19,10 @@ package org.apache.servicemix.common.pac
 import javax.xml.namespace.QName;
 
 /**
+ * <p>
  * Provides a value object for gathering information on a consumes element from
- * a ServiceUnitAnalyzer
+ * a ServiceUnitAnalyzer.
+ * </p>
  * 
  * @author Philip Dodds
  * @version $Revision: 426415 $

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/Provides.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/Provides.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/Provides.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/Provides.java Fri Feb  4 09:05:47 2011
@@ -19,8 +19,10 @@ package org.apache.servicemix.common.pac
 import javax.xml.namespace.QName;
 
 /**
+ * <p>
  * Provides a value object for gathering information on a provides element from
- * a ServiceUnitAnalyzer
+ * a ServiceUnitAnalyzer.
+ * </p>
  * 
  * @author Philip Dodds
  * @version $Revision: 426415 $

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/ServiceUnitAnalyzer.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/ServiceUnitAnalyzer.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/ServiceUnitAnalyzer.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/packaging/ServiceUnitAnalyzer.java Fri Feb  4 09:05:47 2011
@@ -20,11 +20,13 @@ import java.io.File;
 import java.util.List;
 
 /**
+ * <p>
  * Provides a interface that components can implement, if they implement this
  * interface and expose the name of the analyzer in their Maven Project Object
  * Model then the tooling can use this to analyze a Service Unit for the
  * component during packaging to generate the consumes and provides elements for
- * the service unit's jbi.xml
+ * the service unit's jbi.xml.
+ * </p>
  * 
  * @author Philip Dodds
  * @version $Revision: 426415 $
@@ -36,22 +38,28 @@ import java.util.List;
 public interface ServiceUnitAnalyzer {
 
 	/**
+     * <p>
 	 * Initializes the analyzer based on the root directory of an exploded
-	 * service unit
+	 * service unit.
+     * </p>
 	 * 
 	 * @param explodedServiceUnitRoot
 	 */
 	public void init(File explodedServiceUnitRoot);
 
 	/**
-	 * Returns a list of Consumes representing the service unit being analyzed
+     * <p>
+	 * Returns a list of Consumes representing the service unit being analyzed.
+     * </p>
 	 * 
 	 * @return A list of Consumes
 	 */
 	public List getConsumes();
 
 	/**
-	 * Returns a list of Provides representing the service unit being analyzed
+     * <p>
+	 * Returns a list of Provides representing the service unit being analyzed.
+     * </p>
 	 * 
 	 * @return A list of provides
 	 */

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/ScheduleIterator.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/ScheduleIterator.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/ScheduleIterator.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/ScheduleIterator.java Fri Feb  4 09:05:47 2011
@@ -19,15 +19,17 @@ package org.apache.servicemix.common.sch
 import java.util.Date;
 
 /**
+ * <p>
  * Iterator for scheduling.
- * 
- * @author george
- * 
+ * </p>
  */
 public interface ScheduleIterator {
+
     /**
+     * <p>
      * Next execution date of associated task. Implementations should return
      * null to cancel running task.
+     * </p>
      * 
      * @return next date of Execution
      */

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/Scheduler.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/Scheduler.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/Scheduler.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/Scheduler.java Fri Feb  4 09:05:47 2011
@@ -21,10 +21,10 @@ import java.util.Timer;
 import java.util.TimerTask;
 
 /**
- * Class to handle scheduling tasks.
- * <p>
- * This class is thread-safe
  * <p>
+ * Class to handle scheduling tasks.
+ * This class is thread-safe.
+ * </p>
  * 
  * @author George Gastaldi (gastaldi)
  */
@@ -33,38 +33,42 @@ public class Scheduler {
     private Timer timer;
 
     /**
+     * <p>
      * Creates a new Scheduler.
+     * </p>
      */
     public Scheduler() {
         this.timer = new Timer();
     }
 
     /**
+     * <p>
      * Creates a new Daemon Scheduler
+     * </p>
      * 
-     * @param daemon
-     *            Thread must be executed as "daemon".
+     * @param daemon Thread must be executed as "daemon".
      */
     public Scheduler(boolean daemon) {
         this.timer = new Timer(daemon);
     }
 
     /**
-     * Cancels the scheduler task
+     * <p>
+     * Cancels the scheduler task.
+     * </p>
      */
     public void cancel() {
         timer.cancel();
     }
 
     /**
-     * Schedules a task
+     * <p>
+     * Schedules a task.
+     * </p>
      * 
-     * @param task
-     *            scheduled tasl
+     * @param task scheduled task
      * @param iterator
-     *            iterator for schedulingque descreve o agendamento
-     * @throws IllegalStateException
-     *             if task scheduled or canceled
+     * @throws IllegalStateException if task scheduled or canceled.
      */
     public void schedule(SchedulerTask task, ScheduleIterator iterator) {
         Date time = iterator.nextExecution();
@@ -97,7 +101,9 @@ public class Scheduler {
     }
 
     /**
-     * Internal TimerTask instance
+     * <p>
+     * Internal TimerTask instance.
+     * </p>
      */
     class SchedulerTimerTask extends TimerTask {
         private SchedulerTask task;

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/SchedulerTask.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/SchedulerTask.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/SchedulerTask.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/scheduler/SchedulerTask.java Fri Feb  4 09:05:47 2011
@@ -19,7 +19,9 @@ package org.apache.servicemix.common.sch
 import java.util.TimerTask;
 
 /**
+ * <p>
  * A task run by a {@link Scheduler}.
+ * </p>
  * 
  * @author George Gastaldi (gastaldi)
  */
@@ -43,7 +45,9 @@ public abstract class SchedulerTask impl
     public abstract void run();
 
     /**
+     * <p>
      * Cancels task.
+     * </p>
      * 
      * @return true if task already scheduled
      */

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/AuthenticationService.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/AuthenticationService.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/AuthenticationService.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/AuthenticationService.java Fri Feb  4 09:05:47 2011
@@ -17,22 +17,24 @@
 package org.apache.servicemix.common.security;
 
 import java.security.GeneralSecurityException;
-import java.lang.reflect.Proxy;
 import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.Method;
 
 import javax.security.auth.Subject;
 
 /**
+ * <p>
  * Interface for the authentication service.
- *
+ * </p>
  */
 public interface AuthenticationService {
 
     /**
-     * Authenticate a user given its name and credentials.
+     * <p>
+     * Authenticates a user given its name and credentials.
      * Upon sucessfull completion, the subject should be populated
      * with the user known principals.
+     * </p>
      *
      * @param subject the subject to populate
      * @param domain the security domain to use

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/KeystoreInstance.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/KeystoreInstance.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/KeystoreInstance.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/KeystoreInstance.java Fri Feb  4 09:05:47 2011
@@ -26,8 +26,10 @@ import javax.net.ssl.KeyManager;
 import javax.net.ssl.TrustManager;
 
 /**
+ * <p>
  * Based on http://svn.apache.org/repos/asf/geronimo/trunk/modules/management/
  *              src/java/org/apache/geronimo/management/geronimo/KeystoreInstance.java
+ * </p>
  *
  * @version $Rev: $ $Date: $
  */

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/KeystoreManager.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/KeystoreManager.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/KeystoreManager.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/security/KeystoreManager.java Fri Feb  4 09:05:47 2011
@@ -25,17 +25,21 @@ import javax.net.ssl.SSLServerSocketFact
 import javax.net.ssl.SSLSocketFactory;
 
 /**
+ * <p>
  * Based on http://svn.apache.org/repos/asf/geronimo/trunk/modules/management/
  *                      src/java/org/apache/geronimo/management/geronimo/KeystoreManager.java
- *
+ * </p>
  */
 public interface KeystoreManager {
 
     KeystoreInstance getKeystore(String name);
 
     /**
+     * <p>
      * Gets a SSLContext using one Keystore to access the private key
      * and another to provide the list of trusted certificate authorities.
+     * </p>
+     *
      * @param provider
      * @param protocol The SSL protocol to use
      * @param algorithm The SSL algorithm to use
@@ -58,8 +62,11 @@ public interface KeystoreManager {
                                 String algorithm, String keyStore,
                                 String keyAlias, String trustStore) throws GeneralSecurityException;
     /**
+     * <p>
      * Gets a ServerSocketFactory using one Keystore to access the private key
      * and another to provide the list of trusted certificate authorities.
+     * </p>
+     *
      * @param provider
      * @param protocol The SSL protocol to use
      * @param algorithm The SSL algorithm to use
@@ -83,8 +90,11 @@ public interface KeystoreManager {
                                                   String keyAlias, String trustStore) throws GeneralSecurityException;
 
     /**
+     * <p>
      * Gets a SocketFactory using one Keystore to access the private key
      * and another to provide the list of trusted certificate authorities.
+     * </p>
+     *
      * @param provider The SSL provider to use, or null for the default
      * @param protocol The SSL protocol to use
      * @param algorithm The SSL algorithm to use

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/tools/wsdl/Schema.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/tools/wsdl/Schema.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/tools/wsdl/Schema.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/tools/wsdl/Schema.java Fri Feb  4 09:05:47 2011
@@ -23,7 +23,9 @@ import java.util.List;
 import org.w3c.dom.Element;
 
 /**
+ * <p>
  * Contains informations related to a schema.
+ * </p>
  *  
  * @author gnodet
  */
@@ -35,7 +37,10 @@ public class Schema {
     private List<URI> sourceUris;
     
     /**
-     * Add a reference to an imported namespace.
+     * <p>
+     * Adds a reference to an imported namespace.
+     * </p>
+     *
      * @param namespace the namespace to reference
      */
     public void addImport(String namespace) {
@@ -46,6 +51,10 @@ public class Schema {
     }
     
     /**
+     * <p>
+     * Gets the imported namespaces list.
+     * </p>
+     *
      * @return Returns the imports.
      */
     public List<String> getImports() {
@@ -53,6 +62,10 @@ public class Schema {
     }
 
     /**
+     * <p>
+     * Sets the imported namespaces list.
+     * </p>
+     *
      * @param imports The imports to set.
      */
     public void setImports(List<String> imports) {
@@ -60,6 +73,10 @@ public class Schema {
     }
 
     /**
+     * <p>
+     * Gets the root element.
+     * </p>
+     *
      * @return Returns the root.
      */
     public Element getRoot() {
@@ -67,6 +84,10 @@ public class Schema {
     }
 
     /**
+     * <p>
+     * Sets the root element.
+     * </p>
+     *
      * @param root The root to set.
      */
     public void setRoot(Element root) {
@@ -74,6 +95,10 @@ public class Schema {
     }
 
     /**
+     * <p>
+     * Gets the default namespace.
+     * </p>
+     *
      * @return Returns the namespace.
      */
     public String getNamespace() {
@@ -81,6 +106,10 @@ public class Schema {
     }
 
     /**
+     * <p>
+     * Sets the default namespace.
+     * </p>
+     *
      * @param namespace The namespace to set.
      */
     public void setNamespace(String namespace) {
@@ -88,13 +117,21 @@ public class Schema {
     }
 
     /**
-     * @return Returns the sourceUri.
+     * <p>
+     * Gets the source URIs list.
+     * </p>
+     *
+     * @return Returns the source URIs list.
      */
     public List<URI> getSourceUris() {
         return sourceUris;
     }
 
     /**
+     * <p>
+     * Add a new URI in the source URIs list.
+     * </p>
+     *
      * @param sourceUri The sourceUri to set.
      */
     public void addSourceUri(URI sourceUri) {

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/tools/wsdl/SchemaCollection.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/tools/wsdl/SchemaCollection.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/tools/wsdl/SchemaCollection.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/tools/wsdl/SchemaCollection.java Fri Feb  4 09:05:47 2011
@@ -28,8 +28,8 @@ import java.util.Map;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
@@ -37,13 +37,15 @@ import org.w3c.dom.NodeList;
 import org.xml.sax.InputSource;
 
 /**
+ * <p>
  * Collection of schemas.
+ * </p>
  *  
  * @author gnodet
  */
 public class SchemaCollection {
 
-    private static Log log = LogFactory.getLog(SchemaCollection.class);
+    private final Logger logger = LoggerFactory.getLogger(SchemaCollection.class);
     
     private Map<String, Schema> schemas;
     private URI baseUri;
@@ -53,9 +55,7 @@ public class SchemaCollection {
     }
     
     public SchemaCollection(URI baseUri) {
-        if (log.isDebugEnabled()) {
-            log.debug("Initializing schema collection with baseUri: " + baseUri);
-        }
+        logger.debug("Initializing schema collection with baseUri: " + baseUri);
         this.baseUri = baseUri;
         this.schemas = new HashMap<String, Schema>();
     }
@@ -84,9 +84,7 @@ public class SchemaCollection {
     }
     
     public void read(String location, URI baseUri) throws Exception {
-        if (log.isDebugEnabled()) {
-            log.debug("Reading schema at '" + location + "' with baseUri '" + baseUri + "'");
-        }
+        logger.debug("Reading schema at '" + location + "' with baseUri '" + baseUri + "'");
         if (baseUri == null) {
             baseUri = this.baseUri;
         }
@@ -150,10 +148,10 @@ public class SchemaCollection {
             Node parentNode = ce.getParentNode();
             Element root = schema.getRoot();
             if (root == parentNode) { 
-                log.debug("Removing child include node: " + ce);
+                logger.debug("Removing child include node: " + ce);
                 schema.getRoot().removeChild(ce);
             } else {
-                log.warn("Skipping child include node removal: " + ce);
+                logger.warn("Skipping child include node removal: " + ce);
             }
 	        if (location != null && !"".equals(location)) {
 	            read(location, baseUri);

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/DOMUtil.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/DOMUtil.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/DOMUtil.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/DOMUtil.java Fri Feb  4 09:05:47 2011
@@ -31,6 +31,8 @@ import javax.xml.transform.TransformerFa
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Attr;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
@@ -38,17 +40,17 @@ import org.w3c.dom.NamedNodeMap;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 /**
- * A collection of W3C DOM helper methods
+ * <p>
+ * A collection of W3C DOM helper methods.
+ * </p>
  *
  * @version $Revision: 564607 $
  */
 public final class DOMUtil {
 
-    private static final Log LOG = LogFactory.getLog(DOMUtil.class);
+    private final static Logger logger = LoggerFactory.getLogger(DOMUtil.class);
+
     private static DocumentBuilderFactory dbf;
     private static Queue builders = new ConcurrentLinkedQueue();
 
@@ -57,7 +59,12 @@ public final class DOMUtil {
     }
 
     /**
-     * Returns the text of the element
+     * <p>
+     * Returns the text of the element.
+     * </p>
+     *
+     * @param element the element.
+     * @return the element text value.
      */
     public static String getElementText(Element element) {
         StringBuffer buffer = new StringBuffer();
@@ -72,7 +79,12 @@ public final class DOMUtil {
     }
 
     /**
-     * Moves the content of the given element to the given element
+     * <p>
+     * Moves the content of the given element to the given element.
+     * </p>
+     *
+     * @param from the source element.
+     * @param to the destination element.
      */
     public static void moveContent(Element from, Element to) {
         // lets move the child nodes across
@@ -85,7 +97,12 @@ public final class DOMUtil {
     }
 
     /**
-     * Copy the attribues on one element to the other
+     * <p>
+     * Copy the attribues on one element to the other.
+     * </p>
+     *
+     * @param from the source element.
+     * @param to the destination element.
      */
     public static void copyAttributes(Element from, Element to) {
         // lets copy across all the remainingattributes
@@ -97,7 +114,12 @@ public final class DOMUtil {
     }
 
     /**
-     * A helper method useful for debugging and logging which will convert the given DOM node into XML text
+     * <p>
+     * A helper method useful for debugging and logging which will convert the given DOM node into XML text.
+     * </p>
+     *
+     * @param node the node.
+     * @return a raw XML string representing the node.
      */
     public static String asXML(Node node) throws TransformerException {
         Transformer transformer = TransformerFactory.newInstance().newTransformer();
@@ -107,7 +129,12 @@ public final class DOMUtil {
     }
 
     /**
-     * A helper method useful for debugging and logging which will convert the given DOM node into XML text
+     * <p>
+     * A helper method useful for debugging and logging which will convert the given DOM node into XML text.
+     * </p>
+     *
+     * @param node the node.
+     * @return a indented XML string representing the node.
      */
     public static String asIndentedXML(Node node) throws TransformerException {
         Transformer transformer = TransformerFactory.newInstance().newTransformer();
@@ -118,7 +145,13 @@ public final class DOMUtil {
     }
 
     /**
-     * Adds the child element with the given text
+     * <p>
+     * Adds the child element with the given text.
+     * </p>
+     *
+     * @param element the element where to add child.
+     * @param name the child elenemt name.
+     * @param textValue the child element text value.
      */
     public static void addChildElement(Element element, String name, Object textValue) {
         Document document = element.getOwnerDocument();
@@ -131,11 +164,13 @@ public final class DOMUtil {
     }
 
     /**
-     * Creates a QName instance from the given namespace context for the given qualifiedName
+     * <p>
+     * Creates a QName instance from the given namespace context for the given qualifiedName.
+     * </p>
      *
-     * @param element       the element to use as the namespace context
-     * @param qualifiedName the fully qualified name
-     * @return the QName which matches the qualifiedName
+     * @param element the element to use as the namespace context.
+     * @param qualifiedName the fully qualified name.
+     * @return the QName which matches the qualifiedName.
      */
     public static QName createQName(Element element, String qualifiedName) {
         int index = qualifiedName.indexOf(':');
@@ -154,15 +189,21 @@ public final class DOMUtil {
     }
 
     /**
-     * Recursive method to find a given attribute value
+     * <p>
+     * Recursive method to find a given attribute value.
+     * </p>
+     *
+     * @param element the element where to looking for attribute.
+     * @param attributeName the attribute name to look for.
+     * @return the value of the given attribute.
      */
     public static String recursiveGetAttributeValue(Element element, String attributeName) {
         String answer = null;
         try {
             answer = element.getAttribute(attributeName);
         } catch (Exception e) {
-            if (LOG.isTraceEnabled()) {
-                LOG.trace("Caught exception looking up attribute: " + attributeName + " on element: " + element + ". Cause: " + e, e);
+            if (logger.isTraceEnabled()) {
+                logger.trace("Caught exception looking up attribute: " + attributeName + " on element: " + element + ". Cause: " + e, e);
             }
         }
         if (answer == null || answer.length() == 0) {
@@ -175,9 +216,12 @@ public final class DOMUtil {
     }
 
     /**
-     * Get the first child element
-     * @param parent
-     * @return
+     * <p>
+     * Gets the first child element.
+     * </p>
+     *
+     * @param parent the parent node.
+     * @return the first child element.
      */
     public static Element getFirstChildElement(Node parent) {
         NodeList childs = parent.getChildNodes();
@@ -191,9 +235,12 @@ public final class DOMUtil {
     }
 
     /**
-     * Get the next sibling element
-     * @param el
-     * @return
+     * <p>
+     * Gets the next sibling element.
+     * </p>
+     *
+     * @param el the base element.
+     * @return the next sibling element.
      */
     public static Element getNextSiblingElement(Element el) {
         for (Node n = el.getNextSibling(); n != null; n = n.getNextSibling()) {
@@ -205,9 +252,12 @@ public final class DOMUtil {
     }
 
     /**
-     * Build a QName from the element name
-     * @param el
-     * @return
+     * <p>
+     * Builds a QName from the element name.
+     * </p>
+     *
+     * @param el the element.
+     * @return the QName for the given element.
      */
     public static QName getQName(Element el) {
         if (el == null) {
@@ -238,9 +288,11 @@ public final class DOMUtil {
     }
 
     /**
-     * Return a new document, ready to populate.
-     * @return
-     * @throws ParserConfigurationException
+     * <p>
+     * Returns a new document, ready to populate.
+     * </p>
+     *
+     * @return a ready to use Document.
      */
     public static Document newDocument() throws ParserConfigurationException {
         DocumentBuilder builder = getBuilder();

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/MessageUtil.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/MessageUtil.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/MessageUtil.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/MessageUtil.java Fri Feb  4 09:05:47 2011
@@ -45,10 +45,6 @@ import org.xml.sax.SAXException;
 import org.apache.servicemix.jbi.jaxp.SourceTransformer;
 import org.apache.servicemix.jbi.jaxp.StringSource;
 
-/**
- * @author gnodet
- * @version $Revision: 376451 $
- */
 public final class MessageUtil {
 
     private MessageUtil() {
@@ -133,12 +129,12 @@ public final class MessageUtil {
     }
 
     /**
-     * Convert the given {@link NormalizedMessage} instance's content to a re-readable {@link Source} This allows the
+     * <p>
+     * Converts the given {@link NormalizedMessage} instance's content to a re-readable {@link Source} This allows the
      * content to be read more than once (e.g. for XPath evaluation or auditing).
+     * </p>
      *
-     * @param message
-     *            the {@link NormalizedMessage} to convert the content for
-     * @throws MessagingException
+     * @param message the {@link NormalizedMessage} to convert the content for.
      */
     public static void enableContentRereadability(NormalizedMessage message) throws MessagingException {
         if (message.getContent() instanceof StreamSource

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/URIResolver.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/URIResolver.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/URIResolver.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/URIResolver.java Fri Feb  4 09:05:47 2011
@@ -29,9 +29,6 @@ import org.w3c.dom.Text;
 
 public class URIResolver {
 
-    /**
-     * The uri to resolve
-     */
     private String uri;
 
     public URIResolver() {
@@ -78,16 +75,10 @@ public class URIResolver {
         return null;
     }
 
-    /**
-     * @return the uri
-     */
     public String getUri() {
         return uri;
     }
 
-    /**
-     * @param uri the uri to set
-     */
     public void setUri(String uri) {
         this.uri = uri;
     }
@@ -111,11 +102,13 @@ public class URIResolver {
     }
 
     /**
-     * Configure a JBI exchange with the given URI as the target
+     * <p>
+     * Configures a JBI exchange with the given URI as the target.
+     * </p>
      *
-     * @param exchange the exchange to configure
-     * @param context a component context used to resolve endpoints
-     * @param uri the target uri
+     * @param exchange the exchange to configure.
+     * @param context a component context used to resolve endpoints.
+     * @param uri the target URI.
      */
     public static void configureExchange(MessageExchange exchange, ComponentContext context, String uri) {
         if (exchange == null) {

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/URISupport.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/URISupport.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/URISupport.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/util/URISupport.java Fri Feb  4 09:05:47 2011
@@ -28,9 +28,6 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
-/**
- * @version $Revision$
- */
 public class URISupport {
 
     public static class CompositeData {
@@ -133,14 +130,25 @@ public class URISupport {
     }
 
     /**
-     * Removes any URI query from the given uri
+     * <p>
+     * Removes any URI query from the given URI.
+     * </p>
+     *
+     * @param uri the given URI.
+     * @return a clean URI with removed any URI query.
      */
     public static URI removeQuery(URI uri) throws URISyntaxException {
         return createURIWithQuery(uri, null);
     }
 
     /**
-     * Creates a URI with the given query
+     * <p>
+     * Creates a URI with the given query.
+     * </p>
+     *
+     * @param uri the given URI.
+     * @param query the query URI to add.
+     * @return a populated URI including query URI.
      */
     public static URI createURIWithQuery(URI uri, String query) throws URISyntaxException {
         return new URI(uri.getScheme(), uri.getUserInfo(), uri.getHost(), uri.getPort(), uri.getPath(), query, uri.getFragment());
@@ -158,13 +166,6 @@ public class URISupport {
         return rc;
     }
 
-    /**
-     * @param uri
-     * @param rc
-     * @param ssp
-     * @param p
-     * @throws URISyntaxException
-     */
     private static void parseComposite(URI uri, CompositeData rc, String ssp) throws URISyntaxException {
         String componentString;
         String params;
@@ -211,10 +212,6 @@ public class URISupport {
         }
     }
 
-    /**
-     * @param componentString
-     * @return
-     */
     private static String[] splitComponents(String str) {
         List<String> l = new ArrayList<String>();
 
@@ -289,9 +286,13 @@ public class URISupport {
     }
 
     /**
-     * Creates a URI from the original URI and the remaining paramaters
+     * <p>
+     * Creates a URI from the original URI and the remaining paramaters.
+     * </p>
      *
-     * @throws URISyntaxException
+     * @param originalURI the original URI to populate.
+     * @param params the params map to add in the URI.
+     * @return the populated URI.
      */
     public static URI createRemainingURI(URI originalURI, Map params) throws URISyntaxException {
         String s = createQueryString(params);

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/wsdl1/JbiEndpoint.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/wsdl1/JbiEndpoint.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/wsdl1/JbiEndpoint.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/wsdl1/JbiEndpoint.java Fri Feb  4 09:05:47 2011
@@ -25,9 +25,6 @@ import java.net.URI;
 
 public class JbiEndpoint implements ExtensibilityElement, Serializable {
 
-    /**
-     * Generated serial version UID
-     */
     private static final long serialVersionUID = -3118867357618475968L;
     
     protected Boolean required;
@@ -36,59 +33,43 @@ public class JbiEndpoint implements Exte
     protected Role role;
     protected URI defaultMep;
     protected QName defaultOperation;
-    
-    /**
-     * @return Returns the elementType.
-     */
+
     public QName getElementType() {
         return elementType;
     }
-    /**
-     * @param elementType The elementType to set.
-     */
+
     public void setElementType(QName elementType) {
         this.elementType = elementType;
     }
-    /**
-     * @return Returns the required.
-     */
+
     public Boolean getRequired() {
         return required;
     }
-    /**
-     * @param required The required to set.
-     */
+
     public void setRequired(Boolean required) {
         this.required = required;
     }
+
     public Role getRole() {
         return role;
     }
+
     public void setRole(Role role) {
         this.role = role;
     }
-    /**
-     * @return Returns the defaultMep.
-     */
+
     public URI getDefaultMep() {
         return defaultMep;
     }
-    /**
-     * @param defaultMep The defaultMep to set.
-     */
+
     public void setDefaultMep(URI defaultMep) {
         this.defaultMep = defaultMep;
     }
-    
-    /**
-     * @return Returns the defaultOperation.
-     */
+
     public QName getDefaultOperation() {
         return defaultOperation;
     }
-    /**
-     * @param defaultOperation The defaultOperation to set.
-     */
+
     public void setDefaultOperation(QName defaultOperation) {
         this.defaultOperation = defaultOperation;
     }

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/AbstractXBeanDeployer.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/AbstractXBeanDeployer.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/AbstractXBeanDeployer.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/AbstractXBeanDeployer.java Fri Feb  4 09:05:47 2011
@@ -53,9 +53,7 @@ public class AbstractXBeanDeployer exten
      */
     public boolean canDeploy(String serviceUnitName, String serviceUnitRootPath) {
         File xbean = new File(serviceUnitRootPath, getXBeanFile() + ".xml");
-        if (logger.isDebugEnabled()) {
-            logger.debug("Looking for " + xbean + ": " + xbean.exists());
-        }
+        logger.debug("Looking for " + xbean + ": " + xbean.exists());
         return xbean.exists();
     }
 
@@ -101,12 +99,12 @@ public class AbstractXBeanDeployer exten
             validate(su);
             return su;
         } catch (Throwable e) {
-            logger.error(e);
+            logger.error(e.getMessage());
             if (applicationContext != null) {
                 try {
                     applicationContext.destroy();
                 } catch (Exception ne) {
-                    logger.error(ne);
+                    logger.error(ne.getMessage());
                 }
             }
             // There is a chance the thread context classloader has been changed by the xbean kernel,

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/BaseXBeanDeployer.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/BaseXBeanDeployer.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/BaseXBeanDeployer.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/BaseXBeanDeployer.java Fri Feb  4 09:05:47 2011
@@ -24,8 +24,10 @@ import org.apache.servicemix.common.Serv
 import javax.jbi.management.DeploymentException;
 
 /**
+ * <p>
  * A useful XBean deployer which check that the endpoints inherit one of
  * the given allowed endpoint classes.
+ * </p>
  * 
  * @author gnodet
  */

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/ClassLoaderXmlPreprocessor.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/ClassLoaderXmlPreprocessor.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/ParentBeanFactoryPostProcessor.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/ParentBeanFactoryPostProcessor.java Fri Feb  4 09:05:47 2011
@@ -24,8 +24,10 @@ import org.springframework.beans.factory
 import org.springframework.beans.factory.config.ConfigurableListableBeanFactory;
 
 /**
+ * <p>
  * A BeanFactoryPostProcessor which creates a BeanFactory from the given beans
  * and sets it as the parent BeanFactory.
+ * </p>
  * 
  * @author gnodet
  */

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/SimpleBeanFactory.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/SimpleBeanFactory.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/SimpleBeanFactory.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/SimpleBeanFactory.java Fri Feb  4 09:05:47 2011
@@ -25,8 +25,10 @@ import org.springframework.beans.factory
 import org.springframework.beans.factory.BeanDefinitionStoreException;
 
 /**
+ * <p>
  * A simple BeanFactory containing a set of predefined beans which can be used
  * as a parent for another BeanFactory.
+ * </p>
  *  
  * @author gnodet
  */

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/XBeanServiceUnit.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/XBeanServiceUnit.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/XBeanServiceUnit.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/XBeanServiceUnit.java Fri Feb  4 09:05:47 2011
@@ -18,7 +18,6 @@ package org.apache.servicemix.common.xbe
 
 import javax.jbi.JBIException;
 
-import org.apache.servicemix.common.ServiceUnit;
 import org.apache.servicemix.common.DefaultServiceUnit;
 import org.springframework.context.support.AbstractXmlApplicationContext;
 

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/scheduler/SchedulerTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/scheduler/SchedulerTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/scheduler/SchedulerTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/scheduler/SchedulerTest.java Fri Feb  4 09:05:47 2011
@@ -21,17 +21,12 @@ import java.text.DateFormat;
 import java.text.SimpleDateFormat;
 
 import junit.framework.TestCase;
-
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
-import org.apache.servicemix.common.scheduler.Scheduler;
-import org.apache.servicemix.common.scheduler.ScheduleIterator;
-import org.apache.servicemix.common.scheduler.SchedulerTask;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class SchedulerTest extends TestCase {
 
-    private static transient Log logger =  LogFactory.getLog(SchedulerTest.class);
+    private final Logger logger = LoggerFactory.getLogger(SchedulerTest.class);
 
     // Tests Scheduling a task
     public void testSchedule() throws Exception {

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/tools/wsdl/WSDLFlattenerTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/tools/wsdl/WSDLFlattenerTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/tools/wsdl/WSDLFlattenerTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/tools/wsdl/WSDLFlattenerTest.java Fri Feb  4 09:05:47 2011
@@ -29,16 +29,15 @@ import javax.wsdl.xml.WSDLWriter;
 import javax.xml.namespace.QName;
 import javax.xml.parsers.DocumentBuilderFactory;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 public class WSDLFlattenerTest extends TestCase {
 
-    private static transient Log logger =  LogFactory.getLog(WSDLFlattenerTest.class);
+    private final Logger logger = LoggerFactory.getLogger(WSDLFlattenerTest.class);
 
     public void test() throws Exception {
         URL resource = getClass().getClassLoader().getResource("wsn/wsn.wsdl");
@@ -97,7 +96,7 @@ public class WSDLFlattenerTest extends T
         String loc = "b-2.xsd";
         URI rel = SchemaCollection.resolve(base, loc);
         assertEquals("jar:file:/C:/java/servicemix/servicemix-assembly/target/incubator-servicemix-3.0-SNAPSHOT/bin/incubator-servicemix-3.0-SNAPSHOT/bin/../lib/optional/servicemix-wsn2005-3.0-SNAPSHOT.jar!/org/apache/servicemix/wsn/b-2.xsd", rel.toString());
-        logger.info(rel);
+        logger.info(rel.toString());
     }
     
 }

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/wsdl1/JbiEndpointMarshallingTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/wsdl1/JbiEndpointMarshallingTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/wsdl1/JbiEndpointMarshallingTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/wsdl1/JbiEndpointMarshallingTest.java Fri Feb  4 09:05:47 2011
@@ -28,18 +28,12 @@ import javax.wsdl.factory.WSDLFactory;
 import javax.wsdl.xml.WSDLReader;
 import javax.wsdl.xml.WSDLWriter;
 import javax.wsdl.Service;
-import javax.wsdl.WSDLException;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 //import org.apache.servicemix.common.scheduler.Scheduler;
 
 public class JbiEndpointMarshallingTest extends TestCase {
-
-    private static transient Log logger =  LogFactory.getLog(JbiEndpointMarshallingTest.class);
     
     public static final String NS_URI_JBI = "http://servicemix.org/wsdl/jbi/";
 

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/wsdl1/Wsdl1DeployerTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/wsdl1/Wsdl1DeployerTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/wsdl1/Wsdl1DeployerTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/test/java/org/apache/servicemix/common/wsdl1/Wsdl1DeployerTest.java Fri Feb  4 09:05:47 2011
@@ -26,8 +26,6 @@ import javax.wsdl.WSDLException;
 import javax.wsdl.extensions.ExtensibilityElement;
 import javax.wsdl.xml.WSDLReader;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.common.ServiceMixComponent;
 import org.apache.servicemix.common.endpoints.AbstractEndpoint;
 
@@ -38,8 +36,6 @@ import org.apache.servicemix.common.Cont
 import junit.framework.TestCase;
 
 public class Wsdl1DeployerTest extends TestCase {
-
-    private static transient Log logger =  LogFactory.getLog(Wsdl1DeployerTest.class);
         
     // Test to Deploy Service Unit
     public void testDeploy() throws Exception {

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap/src/main/java/org/apache/servicemix/soap/SoapHelper.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap/src/main/java/org/apache/servicemix/soap/SoapHelper.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap/src/main/java/org/apache/servicemix/soap/SoapHelper.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap/src/main/java/org/apache/servicemix/soap/SoapHelper.java Fri Feb  4 09:05:47 2011
@@ -43,8 +43,6 @@ import javax.wsdl.factory.WSDLFactory;
 import javax.wsdl.xml.WSDLReader;
 import javax.xml.namespace.QName;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.common.JbiConstants;
 import org.apache.servicemix.jbi.jaxp.W3CDOMStreamWriter;
 import org.apache.servicemix.soap.marshalers.JBIMarshaler;
@@ -52,6 +50,8 @@ import org.apache.servicemix.soap.marsha
 import org.apache.servicemix.soap.marshalers.SoapMessage;
 import org.apache.servicemix.soap.marshalers.SoapWriter;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 
 import com.ibm.wsdl.Constants;
@@ -65,7 +65,7 @@ import com.ibm.wsdl.Constants;
  */
 public class SoapHelper {
 
-    private static final Log logger = LogFactory.getLog(SoapHelper.class);
+    private final Logger logger = LoggerFactory.getLogger(SoapHelper.class);
 
     private SoapEndpoint endpoint;
     private List policies;
@@ -370,9 +370,7 @@ public class SoapHelper {
                             definitions.put(key, definition);
                         } catch (WSDLException e) {
                             logger.info("Could not read wsdl from endpoint descriptor: " + e.getMessage());
-                            if (logger.isDebugEnabled()) {
-                                logger.debug("Could not read wsdl from endpoint descriptor", e);
-                            }
+                            logger.debug("Could not read wsdl from endpoint descriptor", e);
                         }
                     }
                 }

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/handlers/dom/DomHandlerTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/handlers/dom/DomHandlerTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/handlers/dom/DomHandlerTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/handlers/dom/DomHandlerTest.java Fri Feb  4 09:05:47 2011
@@ -16,15 +16,14 @@
  */
 package org.apache.servicemix.soap.handlers.dom;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import junit.framework.TestCase;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class DomHandlerTest extends TestCase {
 
 	private DomHandler domHandler;
-	private static transient Log log = LogFactory.getLog(DomHandlerTest.class);
+	private final Logger logger = LoggerFactory.getLogger(DomHandlerTest.class);
 	
 	protected void setUp() throws Exception {
 		super.setUp();
@@ -45,7 +44,7 @@ public class DomHandlerTest extends Test
 			fail("setRequired to true should throw an UnsupportedOperationException");
 		} catch (UnsupportedOperationException uoe) {
 			// test passes
-			log.info("setRequired method threw the expected exception.");
+			logger.info("setRequired method threw the expected exception.");
 		}
 	}
 

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/handlers/security/WSSecurityHandlerTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/handlers/security/WSSecurityHandlerTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/handlers/security/WSSecurityHandlerTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/handlers/security/WSSecurityHandlerTest.java Fri Feb  4 09:05:47 2011
@@ -21,12 +21,12 @@ import java.net.URL;
 import java.security.Principal;
 import java.util.List;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.jbi.jaxp.StringSource;
 import org.apache.servicemix.jbi.jaxp.W3CDOMStreamWriter;
 import org.apache.servicemix.jbi.security.auth.impl.JAASAuthenticationService;
@@ -46,7 +46,7 @@ import org.springframework.core.io.Class
 
 public class WSSecurityHandlerTest extends TestCase {
 
-    private static transient Log log = LogFactory.getLog(WSSecurityHandlerTest.class);
+    private final static Logger logger = LoggerFactory.getLogger(WSSecurityHandlerTest.class);
 
     static {
         String path = System.getProperty("java.security.auth.login.config");
@@ -57,7 +57,7 @@ public class WSSecurityHandlerTest exten
                 System.setProperty("java.security.auth.login.config", path);
             }
         }
-        log.info("Path to login config: " + path);
+        logger.info("Path to login config: " + path);
     }
 
     public void testUserNameToken() throws Exception {
@@ -117,7 +117,7 @@ public class WSSecurityHandlerTest exten
         handler.onSend(ctx);
         
         Document doc = ctx.getInMessage().getDocument();
-        log.info(DOMUtil.asXML(doc));
+        logger.info(DOMUtil.asXML(doc));
         
         handler.setReceiveAction(WSHandlerConstants.SIGNATURE);
         handler.onReceive(ctx);
@@ -157,11 +157,11 @@ public class WSSecurityHandlerTest exten
         handler.setUsername("myalias");
         crypto.setKeyPassword("myAliasPassword");
         handler.setReceiveAction(WSHandlerConstants.SIGNATURE);
-        log.info("testSignatureServer BEFORE onReceive");
+        logger.info("testSignatureServer BEFORE onReceive");
         Document doc = ctx.getInMessage().getDocument();
-        log.info(DOMUtil.asXML(doc));
+        logger.info(DOMUtil.asXML(doc));
         handler.onReceive(ctx);
-        log.info("testSignatureServer AFTER onReceive");
+        logger.info("testSignatureServer AFTER onReceive");
         List l = (List) ctx.getProperty(WSHandlerConstants.RECV_RESULTS);
         assertNotNull(l);
         assertEquals(1, l.size());

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/marshalers/FaultTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/marshalers/FaultTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/marshalers/FaultTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/marshalers/FaultTest.java Fri Feb  4 09:05:47 2011
@@ -20,21 +20,22 @@ import java.io.ByteArrayOutputStream;
 
 import javax.xml.namespace.QName;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.jbi.jaxp.SourceTransformer;
 import org.apache.servicemix.jbi.jaxp.StringSource;
 import org.apache.servicemix.jbi.util.DOMUtil;
 import org.apache.servicemix.soap.SoapFault;
 
 public class FaultTest extends TestCase {
-    private static transient Log log = LogFactory.getLog(FaultTest.class);
+
+    private final Logger logger = LoggerFactory.getLogger(FaultTest.class);
 
     private SourceTransformer sourceTransformer = new SourceTransformer();
     
@@ -82,7 +83,7 @@ public class FaultTest extends TestCase 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         writer.write(baos);
         
-        log.info("Resulting Fault: \n" + baos);
+        logger.info("Resulting Fault: \n" + baos);
     }
 
     public void testReadSoap11UsingDom() throws Exception {
@@ -132,7 +133,7 @@ public class FaultTest extends TestCase 
         msg.setFault(fault);
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         marshaler.createWriter(msg).write(baos);
-        log.info(baos.toString());
+        logger.info(baos.toString());
 
         Node node = sourceTransformer.toDOMNode(new StringSource(baos.toString()));
         Element e = ((Document) node).getDocumentElement();
@@ -169,7 +170,7 @@ public class FaultTest extends TestCase 
         msg.setFault(fault);
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         marshaler.createWriter(msg).write(baos);
-        log.info(baos.toString());
+        logger.info(baos.toString());
 
         Node node = sourceTransformer.toDOMNode(new StringSource(baos.toString()));
         Element e = ((Document) node).getDocumentElement();

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/marshalers/SoapMessageMarshalerTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/marshalers/SoapMessageMarshalerTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/marshalers/SoapMessageMarshalerTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap/src/test/java/org/apache/servicemix/soap/marshalers/SoapMessageMarshalerTest.java Fri Feb  4 09:05:47 2011
@@ -36,13 +36,13 @@ import javax.xml.transform.stream.Stream
 
 import junit.framework.TestCase;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.jbi.jaxp.BytesSource;
 import org.apache.servicemix.jbi.jaxp.SourceTransformer;
 import org.apache.servicemix.jbi.util.DOMUtil;
 import org.apache.servicemix.jbi.util.FileUtil;
 import org.apache.xpath.CachedXPathAPI;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.DocumentFragment;
 import org.w3c.dom.Element;
@@ -56,7 +56,7 @@ import org.w3c.dom.traversal.NodeIterato
  */
 public class SoapMessageMarshalerTest extends TestCase {
 
-	private static final Log log = LogFactory.getLog(SoapMessageMarshalerTest.class);
+	private final Logger logger = LoggerFactory.getLogger(SoapMessageMarshalerTest.class);
 	
 	private SourceTransformer sourceTransformer = new SourceTransformer();
 	
@@ -78,7 +78,7 @@ public class SoapMessageMarshalerTest ex
 		msg.setSource(new StreamSource(getClass().getResourceAsStream("soap.xml")));
 		ByteArrayOutputStream baos = new ByteArrayOutputStream();
 		marshaler.createWriter(msg).write(baos);
-		log.info(baos.toString());
+		logger.info(baos.toString());
 		
 		SoapMessage msg2 = marshaler.createReader().read(new ByteArrayInputStream(baos.toByteArray()));
 		assertNotNull(msg2);
@@ -98,7 +98,7 @@ public class SoapMessageMarshalerTest ex
 		ByteArrayOutputStream baos = new ByteArrayOutputStream();
 		SoapWriter writer = marshaler.createWriter(msg);
 		writer.write(baos);
-		log.info(baos.toString());
+		logger.info(baos.toString());
 		
 		SoapMessage msg2 = marshaler.createReader().read(new ByteArrayInputStream(baos.toByteArray()), writer.getContentType());
 		assertNotNull(msg2);
@@ -181,7 +181,7 @@ public class SoapMessageMarshalerTest ex
 		ByteArrayOutputStream baos = new ByteArrayOutputStream();
 		SoapWriter writer = marshaler.createWriter(msg);
 		writer.write(baos);
-		log.info(baos.toString());
+		logger.info(baos.toString());
 		
 		SoapMessage msg2 = marshaler.createReader().read(new ByteArrayInputStream(baos.toByteArray()), writer.getContentType());
 		assertNotNull(msg2);
@@ -213,7 +213,7 @@ public class SoapMessageMarshalerTest ex
         message.saveChanges();
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         message.writeTo(baos);
-        log.info(baos.toString());
+        logger.info(baos.toString());
         
         SoapMarshaler marshaler = new SoapMarshaler(true);
         SoapMessage msg = marshaler.createReader().read(new ByteArrayInputStream(baos.toByteArray()), multipart.getContentType());
@@ -221,7 +221,7 @@ public class SoapMessageMarshalerTest ex
         SoapWriter writer = marshaler.createWriter(msg);
         baos = new ByteArrayOutputStream();
         writer.write(baos);
-        log.info(baos.toString());
+        logger.info(baos.toString());
     }
 
     private void checkHeadersForServiceName(Iterator headers) throws Exception {

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap2/pom.xml
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap2/pom.xml?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap2/pom.xml (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap2/pom.xml Fri Feb  4 09:05:47 2011
@@ -56,8 +56,9 @@
             <artifactId>servicemix-common</artifactId>
         </dependency>
         <dependency>
-            <groupId>commons-logging</groupId>
-            <artifactId>commons-logging</artifactId>
+            <groupId>org.slf4j</groupId>
+            <artifactId>slf4j-api</artifactId>
+            <scope>provided</scope>
         </dependency>
         <dependency>
             <groupId>org.apache.geronimo.specs</groupId>
@@ -136,6 +137,11 @@
             <artifactId>xalan</artifactId>
             <scope>test</scope>
         </dependency>
+        <dependency>
+            <groupId>org.slf4j</groupId>
+            <artifactId>slf4j-log4j12</artifactId>
+            <scope>test</scope>
+        </dependency>
     </dependencies>
 
     <build>

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap2/src/main/java/org/apache/servicemix/soap/core/PhaseInterceptorChain.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap2/src/main/java/org/apache/servicemix/soap/core/PhaseInterceptorChain.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap2/src/main/java/org/apache/servicemix/soap/core/PhaseInterceptorChain.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap2/src/main/java/org/apache/servicemix/soap/core/PhaseInterceptorChain.java Fri Feb  4 09:05:47 2011
@@ -21,11 +21,11 @@ import java.util.Collection;
 import java.util.List;
 import java.util.ListIterator;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.soap.api.Interceptor;
 import org.apache.servicemix.soap.api.InterceptorChain;
 import org.apache.servicemix.soap.api.Message;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * A PhaseInterceptorChain orders Interceptors according 
@@ -35,7 +35,7 @@ import org.apache.servicemix.soap.api.Me
  */
 public class PhaseInterceptorChain implements InterceptorChain {
 
-    private static final Log LOG = LogFactory.getLog(PhaseInterceptorChain.class);
+    private final Logger logger = LoggerFactory.getLogger(PhaseInterceptorChain.class);
     
     private final List<Interceptor> interceptors = new ArrayList<Interceptor>();
     
@@ -56,9 +56,7 @@ public class PhaseInterceptorChain imple
     }
 
     public void add(Interceptor i) {
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Adding interceptor " + i.getId());
-        }
+        logger.debug("Adding interceptor " + i.getId());
         insertInterceptor(i);
     }
 
@@ -79,21 +77,21 @@ public class PhaseInterceptorChain imple
         try {
             while (iterator.hasNext()) {
                 Interceptor currentInterceptor = iterator.next();
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("Invoking handleMessage on interceptor " + currentInterceptor.getId());
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Invoking handleMessage on interceptor " + currentInterceptor.getId());
                 }
                 currentInterceptor.handleMessage(message);
             }
         } catch (RuntimeException ex) {
-            if (LOG.isInfoEnabled()) {
-                LOG.info("Interceptor has thrown exception, unwinding now", ex);
+            if (logger.isInfoEnabled()) {
+                logger.info("Interceptor has thrown exception, unwinding now", ex);
             }
             message.setContent(Exception.class, ex);
             // Unwind
             while (iterator.hasPrevious()) {
                 Interceptor currentInterceptor = iterator.previous();
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("Invoking handleFault on interceptor " + currentInterceptor.getId());
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Invoking handleFault on interceptor " + currentInterceptor.getId());
                 }
                 currentInterceptor.handleFault(message);
             }

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/HelloWorldSoapTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/HelloWorldSoapTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/HelloWorldSoapTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/HelloWorldSoapTest.java Fri Feb  4 09:05:47 2011
@@ -33,13 +33,13 @@ import javax.xml.transform.stream.Stream
 import javax.xml.transform.stream.StreamSource;
 import javax.xml.transform.dom.DOMSource;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.soap.api.InterceptorProvider.Phase;
 import org.apache.servicemix.soap.api.Message;
 import org.apache.servicemix.soap.api.model.Binding;
@@ -58,7 +58,8 @@ import org.apache.servicemix.tck.mock.Mo
 import org.apache.servicemix.tck.mock.MockMessageExchange;
 
 public class HelloWorldSoapTest extends TestCase {
-    private static transient Log log = LogFactory.getLog(HelloWorldSoapTest.class);
+
+    private final Logger logger = LoggerFactory.getLogger(HelloWorldSoapTest.class);
 
 //    static {
 //        String conf = System.getProperty("log4j.configuration");
@@ -93,7 +94,7 @@ public class HelloWorldSoapTest extends 
         Document doc = DomUtil.parse(nm.getContent());
         baos = new ByteArrayOutputStream();
         DomUtil.getTransformerFactory().newTransformer().transform(new DOMSource(doc), new StreamResult(baos));
-        log.info(baos.toString());
+        logger.info(baos.toString());
         if (useDom) {
             nm.setContent(new DOMSource(doc));
         } else {
@@ -156,7 +157,7 @@ public class HelloWorldSoapTest extends 
         msgOut.setContent(NormalizedMessage.class, nm);
         msgOut.put(SoapVersion.class, msg.get(SoapVersion.class));
         phaseOut.doIntercept(msgOut);
-        log.info(baos.toString());
+        logger.info(baos.toString());
 
         Document node = DomUtil.parse(new ByteArrayInputStream(baos.toByteArray()));
 
@@ -211,7 +212,7 @@ public class HelloWorldSoapTest extends 
         Document doc = DomUtil.parse(nm.getContent());
         baos = new ByteArrayOutputStream();
         DomUtil.getTransformerFactory().newTransformer().transform(new DOMSource(doc), new StreamResult(baos));
-        log.info(baos.toString());
+        logger.info(baos.toString());
         nm.setContent(new DOMSource(doc));
         
         // check jbi message element
@@ -252,7 +253,7 @@ public class HelloWorldSoapTest extends 
         msgOut.setContent(NormalizedMessage.class, nm);
         msgOut.put(SoapVersion.class, msg.get(SoapVersion.class));
         phaseOut.doIntercept(msgOut);
-        log.info(baos.toString());
+        logger.info(baos.toString());
         
         Document node = DomUtil.parse(new ByteArrayInputStream(baos.toByteArray()));
         Element envelope = DomUtil.getFirstChildElement(node);
@@ -290,7 +291,7 @@ public class HelloWorldSoapTest extends 
         Document doc = DomUtil.parse(nm.getContent());
         baos = new ByteArrayOutputStream();
         DomUtil.getTransformerFactory().newTransformer().transform(nm.getContent(), new StreamResult(baos));
-        log.info(baos.toString());
+        logger.info(baos.toString());
         
         Element root = DomUtil.getFirstChildElement(doc);
         assertNotNull(root);
@@ -317,7 +318,7 @@ public class HelloWorldSoapTest extends 
             phaseOutFault.doIntercept(msgOut);
         }
 
-        log.info(baos.toString());
+        logger.info(baos.toString());
         Document node = DomUtil.parse(new ByteArrayInputStream(baos.toByteArray()));
         
         Element envelope = DomUtil.getFirstChildElement(node);
@@ -352,7 +353,7 @@ public class HelloWorldSoapTest extends 
 
         baos = new ByteArrayOutputStream();
         DomUtil.getTransformerFactory().newTransformer().transform(nm.getContent(), new StreamResult(baos));
-        log.info(baos.toString());
+        logger.info(baos.toString());
 
         Element root = DomUtil.getFirstChildElement(doc);
         assertNotNull(msg);
@@ -423,7 +424,7 @@ public class HelloWorldSoapTest extends 
         msgOut.setContent(NormalizedMessage.class, nm);
         msgOut.put(SoapVersion.class, msg.get(SoapVersion.class));
         phaseOut.doIntercept(msgOut);
-        log.info(baos.toString());
+        logger.info(baos.toString());
         
         Document node = DomUtil.parse(new ByteArrayInputStream(baos.toByteArray()));
         Element envelope = DomUtil.getFirstChildElement(node);
@@ -473,7 +474,7 @@ public class HelloWorldSoapTest extends 
 
         baos = new ByteArrayOutputStream();
         DomUtil.getTransformerFactory().newTransformer().transform(nm.getContent(), new StreamResult(baos));
-        log.info(baos.toString());
+        logger.info(baos.toString());
         
         // check jbi message element
         Element root = DomUtil.getFirstChildElement(doc);
@@ -504,7 +505,7 @@ public class HelloWorldSoapTest extends 
         msgOut.setContent(NormalizedMessage.class, nm);
         msgOut.put(SoapVersion.class, msg.get(SoapVersion.class));
         phaseOut.doIntercept(msgOut);
-        log.info(baos.toString());
+        logger.info(baos.toString());
         
         Document node = DomUtil.parse(new ByteArrayInputStream(baos.toByteArray()));
         Element envelope = DomUtil.getFirstChildElement(node);
@@ -531,7 +532,7 @@ public class HelloWorldSoapTest extends 
         WSIBPValidator validator = new WSIBPValidator(def);
         if (!validator.isValid()) {
             for (String err : validator.getErrors()) {
-                log.info(err);
+                logger.info(err);
             }
         }
         Service svc = (Service) def.getServices().values().iterator().next();

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/PersonHttpTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/PersonHttpTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/PersonHttpTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/PersonHttpTest.java Fri Feb  4 09:05:47 2011
@@ -26,13 +26,13 @@ import javax.jbi.messaging.NormalizedMes
 import javax.xml.namespace.QName;
 import javax.xml.transform.stream.StreamResult;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.soap.api.InterceptorProvider.Phase;
 import org.apache.servicemix.soap.api.Message;
 import org.apache.servicemix.soap.api.model.Binding;
@@ -50,7 +50,8 @@ import org.apache.woden.wsdl20.Endpoint;
 import org.apache.woden.wsdl20.xml.DescriptionElement;
 
 public class PersonHttpTest extends TestCase {
-    private static transient Log log = LogFactory.getLog(PersonHttpTest.class);
+
+    private final Logger logger = LoggerFactory.getLogger(PersonHttpTest.class);
 
     private static Binding<?> binding = getBinding("Person.wsdl2");
 
@@ -72,7 +73,7 @@ public class PersonHttpTest extends Test
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         DomUtil.getTransformerFactory().newTransformer().transform(nm.getContent(), new StreamResult(baos));
-        log.info(baos.toString());
+        logger.info(baos.toString());
 
         assertEquals(new QName("http://example.org/Person", "getPerson"), me.getOperation());
         Element e = DomUtil.getFirstChildElement(doc);
@@ -104,7 +105,7 @@ public class PersonHttpTest extends Test
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         DomUtil.getTransformerFactory().newTransformer().transform(nm.getContent(), new StreamResult(baos));
-        log.info(baos.toString());
+        logger.info(baos.toString());
 
         assertEquals(new QName("http://example.org/Person", "updatePerson"), me.getOperation());
         Element e = DomUtil.getFirstChildElement(doc);
@@ -146,7 +147,7 @@ public class PersonHttpTest extends Test
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         DomUtil.getTransformerFactory().newTransformer().transform(nm.getContent(), new StreamResult(baos));
-        log.info(baos.toString());
+        logger.info(baos.toString());
 
         assertEquals(new QName("http://example.org/Person", "addPerson"), me.getOperation());
         Element e = DomUtil.getFirstChildElement(doc);
@@ -187,7 +188,7 @@ public class PersonHttpTest extends Test
 
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         DomUtil.getTransformerFactory().newTransformer().transform(nm.getContent(), new StreamResult(baos));
-        log.info(baos.toString());
+        logger.info(baos.toString());
 
         assertEquals(new QName("http://example.org/Person", "deletePerson"), me.getOperation());
         Element e = DomUtil.getFirstChildElement(doc);

Modified: servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/bindings/soap/interceptors/SoapInInterceptorTest.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/bindings/soap/interceptors/SoapInInterceptorTest.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================
--- servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/bindings/soap/interceptors/SoapInInterceptorTest.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-soap2/src/test/java/org/apache/servicemix/soap/bindings/soap/interceptors/SoapInInterceptorTest.java Fri Feb  4 09:05:47 2011
@@ -25,16 +25,17 @@ import javax.xml.stream.XMLStreamReader;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.soap.api.Message;
 import org.apache.servicemix.soap.bindings.soap.SoapFault;
 import org.apache.servicemix.soap.bindings.soap.SoapVersion;
 import org.apache.servicemix.soap.core.MessageImpl;
 import org.apache.servicemix.soap.interceptors.xml.StaxInInterceptor;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class SoapInInterceptorTest extends TestCase {
-    private static transient Log log = LogFactory.getLog(SoapInInterceptorTest.class);
+
+    private final Logger logger = LoggerFactory.getLogger(SoapInInterceptorTest.class);
 
     private SoapInInterceptor interceptor = new SoapInInterceptor();
     
@@ -56,7 +57,7 @@ public class SoapInInterceptorTest exten
             interceptor.handleMessage(msg);
             fail("Interceptor should have thrown a SoapFault");
         } catch (SoapFault e) {
-            log.info(e.getMessage(), e);
+            logger.info(e.getMessage(), e);
         }
     }
     
@@ -69,7 +70,7 @@ public class SoapInInterceptorTest exten
             interceptor.handleMessage(msg);
             fail("Interceptor should have thrown a SoapFault");
         } catch (SoapFault e) {
-            log.info(e.getMessage(), e);
+            logger.info(e.getMessage(), e);
         }
     }
     
@@ -82,7 +83,7 @@ public class SoapInInterceptorTest exten
             interceptor.handleMessage(msg);
             fail("Interceptor should have thrown a SoapFault");
         } catch (SoapFault e) {
-            log.info(e.getMessage(), e);
+            logger.info(e.getMessage(), e);
         }
     }
--- servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/ClassLoaderXmlPreprocessor.java (original)
+++ servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/ClassLoaderXmlPreprocessor.java Fri Feb  4 09:05:47 2011
@@ -38,6 +38,8 @@ import org.apache.servicemix.common.util
 import org.apache.xbean.classloader.JarFileClassLoader;
 import org.apache.xbean.spring.context.SpringApplicationContext;
 import org.apache.xbean.spring.context.SpringXmlPreprocessor;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.springframework.beans.FatalBeanException;
 import org.springframework.beans.factory.xml.XmlBeanDefinitionReader;
 import org.w3c.dom.Document;
@@ -46,14 +48,18 @@ import org.w3c.dom.NodeList;
 import org.w3c.dom.Text;
 
 /**
  * An advanced xml preprocessor that will create a default classloader for the SU if none
  * is configured.
+ * </p>
  * 
  * @author gnodet
  * @author jbonofre
  */
 public class ClassLoaderXmlPreprocessor implements SpringXmlPreprocessor {
 
+    private final Logger logger = LoggerFactory.getLogger(ClassLoaderXmlPreprocessor.class);
+
     public static final String CLASSPATH_XML = "classpath.xml";
     public static final String LIB_DIR = "/lib";
     
@@ -76,9 +82,11 @@ public class ClassLoaderXmlPreprocessor 
     public void preprocess(SpringApplicationContext applicationContext, XmlBeanDefinitionReader reader, Document document) {
         // determine the classLoader
         ClassLoader classLoader;
+        logger.debug("Get the classpath elements from xbean descriptor.");
         NodeList classpathElements = document.getDocumentElement().getElementsByTagName("classpath");
         if (classpathElements.getLength() == 0) {
             // Check if a classpath.xml file exists in the root of the SU
+            logger.debug("Check if a classpath.xml file exists in the SU root.");
             List<URL> classpathUrls = getResources(CLASSPATH_XML);
             if (classpathUrls.size() == 1) {
                 DocumentBuilder builder = null;
@@ -207,6 +215,7 @@ public class ClassLoaderXmlPreprocessor 
      * @return the jar location URLs.
      */
     protected List<URL> getJarResources(String location) {
+        logger.debug("Get jar resources from " + location);
         List<URL> urls = new LinkedList<URL>();
         // get the !/ separator index
         int separatorIndex = location.indexOf("!/");
@@ -249,7 +258,7 @@ public class ClassLoaderXmlPreprocessor 
     /**
      * <p>
      * Get the URLs for a file: protocol based location. This methods supports
-     * regexp to add severnal entries.
+     * regexp to add several entries.
      * </p>
      * 
      * <pre>
@@ -261,6 +270,7 @@ public class ClassLoaderXmlPreprocessor 
      * @return
      */
     protected List<URL> getFileResources(String location) {
+        logger.debug("Get file resources from " + location);
         List<URL> urls = new LinkedList<URL>();
         int starIndex = location.indexOf("*");
         if (starIndex == -1) {
@@ -46,14 +48,18 @@ import org.w3c.dom.NodeList;
 
 /**
- * An advanced xml preprocessor that will create a default classloader for the SU if none
+ * <p>
+ * An advanced xml preprocessor that will create a default class loader for the SU if none
  * is configured.

Modified: servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/ParentBeanFactoryPostProcessor.java
URL: http://svn.apache.org/viewvc/servicemix/components/trunk/shared-libraries/servicemix-common/src/main/java/org/apache/servicemix/common/xbean/ParentBeanFactoryPostProcessor.java?rev=1067118&r1=1067117&r2=1067118&view=diff
==============================================================================